import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { TranslateServiceException as __BaseException } from "./TranslateServiceException";

export interface Term {
    
    SourceText?: string;
    
    TargetText?: string;
}
export declare namespace Term {
    
    const filterSensitiveLog: (obj: Term) => any;
}

export interface AppliedTerminology {
    
    Name?: string;
    
    Terms?: Term[];
}
export declare namespace AppliedTerminology {
    
    const filterSensitiveLog: (obj: AppliedTerminology) => any;
}

export declare class ConflictException extends __BaseException {
    readonly name: "ConflictException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export declare enum EncryptionKeyType {
    KMS = "KMS"
}

export interface EncryptionKey {
    
    Type: EncryptionKeyType | string | undefined;
    
    Id: string | undefined;
}
export declare namespace EncryptionKey {
    
    const filterSensitiveLog: (obj: EncryptionKey) => any;
}
export declare enum ParallelDataFormat {
    CSV = "CSV",
    TMX = "TMX",
    TSV = "TSV"
}

export interface ParallelDataConfig {
    
    S3Uri: string | undefined;
    
    Format: ParallelDataFormat | string | undefined;
}
export declare namespace ParallelDataConfig {
    
    const filterSensitiveLog: (obj: ParallelDataConfig) => any;
}
export interface CreateParallelDataRequest {
    
    Name: string | undefined;
    
    Description?: string;
    
    ParallelDataConfig: ParallelDataConfig | undefined;
    
    EncryptionKey?: EncryptionKey;
    
    ClientToken?: string;
}
export declare namespace CreateParallelDataRequest {
    
    const filterSensitiveLog: (obj: CreateParallelDataRequest) => any;
}
export declare enum ParallelDataStatus {
    ACTIVE = "ACTIVE",
    CREATING = "CREATING",
    DELETING = "DELETING",
    FAILED = "FAILED",
    UPDATING = "UPDATING"
}
export interface CreateParallelDataResponse {
    
    Name?: string;
    
    Status?: ParallelDataStatus | string;
}
export declare namespace CreateParallelDataResponse {
    
    const filterSensitiveLog: (obj: CreateParallelDataResponse) => any;
}

export declare class InternalServerException extends __BaseException {
    readonly name: "InternalServerException";
    readonly $fault: "server";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<InternalServerException, __BaseException>);
}

export declare class InvalidParameterValueException extends __BaseException {
    readonly name: "InvalidParameterValueException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<InvalidParameterValueException, __BaseException>);
}

export declare class InvalidRequestException extends __BaseException {
    readonly name: "InvalidRequestException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<InvalidRequestException, __BaseException>);
}

export declare class LimitExceededException extends __BaseException {
    readonly name: "LimitExceededException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<LimitExceededException, __BaseException>);
}

export declare class TooManyRequestsException extends __BaseException {
    readonly name: "TooManyRequestsException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<TooManyRequestsException, __BaseException>);
}

export declare class ConcurrentModificationException extends __BaseException {
    readonly name: "ConcurrentModificationException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ConcurrentModificationException, __BaseException>);
}
export interface DeleteParallelDataRequest {
    
    Name: string | undefined;
}
export declare namespace DeleteParallelDataRequest {
    
    const filterSensitiveLog: (obj: DeleteParallelDataRequest) => any;
}
export interface DeleteParallelDataResponse {
    
    Name?: string;
    
    Status?: ParallelDataStatus | string;
}
export declare namespace DeleteParallelDataResponse {
    
    const filterSensitiveLog: (obj: DeleteParallelDataResponse) => any;
}

export declare class ResourceNotFoundException extends __BaseException {
    readonly name: "ResourceNotFoundException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>);
}
export interface DeleteTerminologyRequest {
    
    Name: string | undefined;
}
export declare namespace DeleteTerminologyRequest {
    
    const filterSensitiveLog: (obj: DeleteTerminologyRequest) => any;
}
export interface DescribeTextTranslationJobRequest {
    
    JobId: string | undefined;
}
export declare namespace DescribeTextTranslationJobRequest {
    
    const filterSensitiveLog: (obj: DescribeTextTranslationJobRequest) => any;
}

export interface InputDataConfig {
    
    S3Uri: string | undefined;
    
    ContentType: string | undefined;
}
export declare namespace InputDataConfig {
    
    const filterSensitiveLog: (obj: InputDataConfig) => any;
}

export interface JobDetails {
    
    TranslatedDocumentsCount?: number;
    
    DocumentsWithErrorsCount?: number;
    
    InputDocumentsCount?: number;
}
export declare namespace JobDetails {
    
    const filterSensitiveLog: (obj: JobDetails) => any;
}
export declare enum JobStatus {
    COMPLETED = "COMPLETED",
    COMPLETED_WITH_ERROR = "COMPLETED_WITH_ERROR",
    FAILED = "FAILED",
    IN_PROGRESS = "IN_PROGRESS",
    STOPPED = "STOPPED",
    STOP_REQUESTED = "STOP_REQUESTED",
    SUBMITTED = "SUBMITTED"
}

export interface OutputDataConfig {
    
    S3Uri: string | undefined;
    
    EncryptionKey?: EncryptionKey;
}
export declare namespace OutputDataConfig {
    
    const filterSensitiveLog: (obj: OutputDataConfig) => any;
}
export declare enum Formality {
    FORMAL = "FORMAL",
    INFORMAL = "INFORMAL"
}
export declare enum Profanity {
    MASK = "MASK"
}

export interface TranslationSettings {
    Formality?: Formality | string;
    
    Profanity?: Profanity | string;
}
export declare namespace TranslationSettings {
    
    const filterSensitiveLog: (obj: TranslationSettings) => any;
}

export interface TextTranslationJobProperties {
    
    JobId?: string;
    
    JobName?: string;
    
    JobStatus?: JobStatus | string;
    
    JobDetails?: JobDetails;
    
    SourceLanguageCode?: string;
    
    TargetLanguageCodes?: string[];
    
    TerminologyNames?: string[];
    
    ParallelDataNames?: string[];
    
    Message?: string;
    
    SubmittedTime?: Date;
    
    EndTime?: Date;
    
    InputDataConfig?: InputDataConfig;
    
    OutputDataConfig?: OutputDataConfig;
    
    DataAccessRoleArn?: string;
    
    Settings?: TranslationSettings;
}
export declare namespace TextTranslationJobProperties {
    
    const filterSensitiveLog: (obj: TextTranslationJobProperties) => any;
}
export interface DescribeTextTranslationJobResponse {
    
    TextTranslationJobProperties?: TextTranslationJobProperties;
}
export declare namespace DescribeTextTranslationJobResponse {
    
    const filterSensitiveLog: (obj: DescribeTextTranslationJobResponse) => any;
}
export interface GetParallelDataRequest {
    
    Name: string | undefined;
}
export declare namespace GetParallelDataRequest {
    
    const filterSensitiveLog: (obj: GetParallelDataRequest) => any;
}

export interface ParallelDataDataLocation {
    
    RepositoryType: string | undefined;
    
    Location: string | undefined;
}
export declare namespace ParallelDataDataLocation {
    
    const filterSensitiveLog: (obj: ParallelDataDataLocation) => any;
}

export interface ParallelDataProperties {
    
    Name?: string;
    
    Arn?: string;
    
    Description?: string;
    
    Status?: ParallelDataStatus | string;
    
    SourceLanguageCode?: string;
    
    TargetLanguageCodes?: string[];
    
    ParallelDataConfig?: ParallelDataConfig;
    
    Message?: string;
    
    ImportedDataSize?: number;
    
    ImportedRecordCount?: number;
    
    FailedRecordCount?: number;
    
    SkippedRecordCount?: number;
    
    EncryptionKey?: EncryptionKey;
    
    CreatedAt?: Date;
    
    LastUpdatedAt?: Date;
    
    LatestUpdateAttemptStatus?: ParallelDataStatus | string;
    
    LatestUpdateAttemptAt?: Date;
}
export declare namespace ParallelDataProperties {
    
    const filterSensitiveLog: (obj: ParallelDataProperties) => any;
}
export interface GetParallelDataResponse {
    
    ParallelDataProperties?: ParallelDataProperties;
    
    DataLocation?: ParallelDataDataLocation;
    
    AuxiliaryDataLocation?: ParallelDataDataLocation;
    
    LatestUpdateAttemptAuxiliaryDataLocation?: ParallelDataDataLocation;
}
export declare namespace GetParallelDataResponse {
    
    const filterSensitiveLog: (obj: GetParallelDataResponse) => any;
}
export declare enum TerminologyDataFormat {
    CSV = "CSV",
    TMX = "TMX",
    TSV = "TSV"
}
export interface GetTerminologyRequest {
    
    Name: string | undefined;
    
    TerminologyDataFormat?: TerminologyDataFormat | string;
}
export declare namespace GetTerminologyRequest {
    
    const filterSensitiveLog: (obj: GetTerminologyRequest) => any;
}

export interface TerminologyDataLocation {
    
    RepositoryType: string | undefined;
    
    Location: string | undefined;
}
export declare namespace TerminologyDataLocation {
    
    const filterSensitiveLog: (obj: TerminologyDataLocation) => any;
}
export declare enum Directionality {
    MULTI = "MULTI",
    UNI = "UNI"
}

export interface TerminologyProperties {
    
    Name?: string;
    
    Description?: string;
    
    Arn?: string;
    
    SourceLanguageCode?: string;
    
    TargetLanguageCodes?: string[];
    
    EncryptionKey?: EncryptionKey;
    
    SizeBytes?: number;
    
    TermCount?: number;
    
    CreatedAt?: Date;
    
    LastUpdatedAt?: Date;
    
    Directionality?: Directionality | string;
    
    Message?: string;
    
    SkippedTermCount?: number;
    
    Format?: TerminologyDataFormat | string;
}
export declare namespace TerminologyProperties {
    
    const filterSensitiveLog: (obj: TerminologyProperties) => any;
}
export interface GetTerminologyResponse {
    
    TerminologyProperties?: TerminologyProperties;
    
    TerminologyDataLocation?: TerminologyDataLocation;
    
    AuxiliaryDataLocation?: TerminologyDataLocation;
}
export declare namespace GetTerminologyResponse {
    
    const filterSensitiveLog: (obj: GetTerminologyResponse) => any;
}
export declare enum MergeStrategy {
    OVERWRITE = "OVERWRITE"
}

export interface TerminologyData {
    
    File: Uint8Array | undefined;
    
    Format: TerminologyDataFormat | string | undefined;
    
    Directionality?: Directionality | string;
}
export declare namespace TerminologyData {
    
    const filterSensitiveLog: (obj: TerminologyData) => any;
}
export interface ImportTerminologyRequest {
    
    Name: string | undefined;
    
    MergeStrategy: MergeStrategy | string | undefined;
    
    Description?: string;
    
    TerminologyData: TerminologyData | undefined;
    
    EncryptionKey?: EncryptionKey;
}
export declare namespace ImportTerminologyRequest {
    
    const filterSensitiveLog: (obj: ImportTerminologyRequest) => any;
}
export interface ImportTerminologyResponse {
    
    TerminologyProperties?: TerminologyProperties;
    
    AuxiliaryDataLocation?: TerminologyDataLocation;
}
export declare namespace ImportTerminologyResponse {
    
    const filterSensitiveLog: (obj: ImportTerminologyResponse) => any;
}
export interface ListParallelDataRequest {
    
    NextToken?: string;
    
    MaxResults?: number;
}
export declare namespace ListParallelDataRequest {
    
    const filterSensitiveLog: (obj: ListParallelDataRequest) => any;
}
export interface ListParallelDataResponse {
    
    ParallelDataPropertiesList?: ParallelDataProperties[];
    
    NextToken?: string;
}
export declare namespace ListParallelDataResponse {
    
    const filterSensitiveLog: (obj: ListParallelDataResponse) => any;
}
export interface ListTerminologiesRequest {
    
    NextToken?: string;
    
    MaxResults?: number;
}
export declare namespace ListTerminologiesRequest {
    
    const filterSensitiveLog: (obj: ListTerminologiesRequest) => any;
}
export interface ListTerminologiesResponse {
    
    TerminologyPropertiesList?: TerminologyProperties[];
    
    NextToken?: string;
}
export declare namespace ListTerminologiesResponse {
    
    const filterSensitiveLog: (obj: ListTerminologiesResponse) => any;
}

export declare class InvalidFilterException extends __BaseException {
    readonly name: "InvalidFilterException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<InvalidFilterException, __BaseException>);
}

export interface TextTranslationJobFilter {
    
    JobName?: string;
    
    JobStatus?: JobStatus | string;
    
    SubmittedBeforeTime?: Date;
    
    SubmittedAfterTime?: Date;
}
export declare namespace TextTranslationJobFilter {
    
    const filterSensitiveLog: (obj: TextTranslationJobFilter) => any;
}
export interface ListTextTranslationJobsRequest {
    
    Filter?: TextTranslationJobFilter;
    
    NextToken?: string;
    
    MaxResults?: number;
}
export declare namespace ListTextTranslationJobsRequest {
    
    const filterSensitiveLog: (obj: ListTextTranslationJobsRequest) => any;
}
export interface ListTextTranslationJobsResponse {
    
    TextTranslationJobPropertiesList?: TextTranslationJobProperties[];
    
    NextToken?: string;
}
export declare namespace ListTextTranslationJobsResponse {
    
    const filterSensitiveLog: (obj: ListTextTranslationJobsResponse) => any;
}
export interface StartTextTranslationJobRequest {
    
    JobName?: string;
    
    InputDataConfig: InputDataConfig | undefined;
    
    OutputDataConfig: OutputDataConfig | undefined;
    
    DataAccessRoleArn: string | undefined;
    
    SourceLanguageCode: string | undefined;
    
    TargetLanguageCodes: string[] | undefined;
    
    TerminologyNames?: string[];
    
    ParallelDataNames?: string[];
    
    ClientToken?: string;
    
    Settings?: TranslationSettings;
}
export declare namespace StartTextTranslationJobRequest {
    
    const filterSensitiveLog: (obj: StartTextTranslationJobRequest) => any;
}
export interface StartTextTranslationJobResponse {
    
    JobId?: string;
    
    JobStatus?: JobStatus | string;
}
export declare namespace StartTextTranslationJobResponse {
    
    const filterSensitiveLog: (obj: StartTextTranslationJobResponse) => any;
}

export declare class UnsupportedLanguagePairException extends __BaseException {
    readonly name: "UnsupportedLanguagePairException";
    readonly $fault: "client";
    Message?: string;
    
    SourceLanguageCode?: string;
    
    TargetLanguageCode?: string;
    
    constructor(opts: __ExceptionOptionType<UnsupportedLanguagePairException, __BaseException>);
}
export interface StopTextTranslationJobRequest {
    
    JobId: string | undefined;
}
export declare namespace StopTextTranslationJobRequest {
    
    const filterSensitiveLog: (obj: StopTextTranslationJobRequest) => any;
}
export interface StopTextTranslationJobResponse {
    
    JobId?: string;
    
    JobStatus?: JobStatus | string;
}
export declare namespace StopTextTranslationJobResponse {
    
    const filterSensitiveLog: (obj: StopTextTranslationJobResponse) => any;
}

export declare class DetectedLanguageLowConfidenceException extends __BaseException {
    readonly name: "DetectedLanguageLowConfidenceException";
    readonly $fault: "client";
    Message?: string;
    
    DetectedLanguageCode?: string;
    
    constructor(opts: __ExceptionOptionType<DetectedLanguageLowConfidenceException, __BaseException>);
}

export declare class ServiceUnavailableException extends __BaseException {
    readonly name: "ServiceUnavailableException";
    readonly $fault: "server";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ServiceUnavailableException, __BaseException>);
}

export declare class TextSizeLimitExceededException extends __BaseException {
    readonly name: "TextSizeLimitExceededException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<TextSizeLimitExceededException, __BaseException>);
}
export interface TranslateTextRequest {
    
    Text: string | undefined;
    
    TerminologyNames?: string[];
    
    SourceLanguageCode: string | undefined;
    
    TargetLanguageCode: string | undefined;
    
    Settings?: TranslationSettings;
}
export declare namespace TranslateTextRequest {
    
    const filterSensitiveLog: (obj: TranslateTextRequest) => any;
}
export interface TranslateTextResponse {
    
    TranslatedText: string | undefined;
    
    SourceLanguageCode: string | undefined;
    
    TargetLanguageCode: string | undefined;
    
    AppliedTerminologies?: AppliedTerminology[];
    
    AppliedSettings?: TranslationSettings;
}
export declare namespace TranslateTextResponse {
    
    const filterSensitiveLog: (obj: TranslateTextResponse) => any;
}
export interface UpdateParallelDataRequest {
    
    Name: string | undefined;
    
    Description?: string;
    
    ParallelDataConfig: ParallelDataConfig | undefined;
    
    ClientToken?: string;
}
export declare namespace UpdateParallelDataRequest {
    
    const filterSensitiveLog: (obj: UpdateParallelDataRequest) => any;
}
export interface UpdateParallelDataResponse {
    
    Name?: string;
    
    Status?: ParallelDataStatus | string;
    
    LatestUpdateAttemptStatus?: ParallelDataStatus | string;
    
    LatestUpdateAttemptAt?: Date;
}
export declare namespace UpdateParallelDataResponse {
    
    const filterSensitiveLog: (obj: UpdateParallelDataResponse) => any;
}
